@@ -1,10 +1,10 @@
 ## -*- coding: utf-8 -*-
 ##
 ##  Jonathan Salwan - 2014-05-17 - ROPgadget tool
-## 
+##
 ##  http://twitter.com/JonathanSalwan
 ##  http://shell-storm.org/project/ROPgadget/
-## 
+##
 
 import cmd
 import os
@@ -12,6 +12,7 @@ import re
 import codecs
 import ropgadget.rgutils as rgutils
 import sqlite3
+import binascii
 
 from ropgadget.binary             import Binary
 from capstone                     import CS_MODE_32
@@ -30,7 +31,7 @@ class Core(cmd.Cmd):
 
 
     def __checksBeforeManipulations(self):
-        if self.__binary == None or self.__binary.getBinary() == None or self.__binary.getArch() == None or self.__binary.getArchMode() == None:
+        if self.__binary == None or self.__binary.getBinary() == None or self.__binary.getArch() == None or self.__binary.getArchMode() == None or self.__binary.getEndian() == None:
             return False
         return True
 
@@ -108,7 +109,7 @@ class Core(cmd.Cmd):
             vaddr = gadget["vaddr"]
             insts = gadget["gadget"]
             bytes = gadget["bytes"]
-            bytesStr = " // " + bytes.encode('hex') if self.__options.dump else ""
+            bytesStr = " // " + binascii.hexlify(bytes).decode('utf8') if self.__options.dump else ""
 
             print(("0x%08x" %(vaddr) if arch == CS_MODE_32 else "0x%016x" %(vaddr)) + " : %s" %(insts) + bytesStr)
 
@@ -201,7 +202,7 @@ class Core(cmd.Cmd):
         if   self.__options.string:   return self.__lookingForAString(self.__options.string)
         elif self.__options.opcode:   return self.__lookingForOpcodes(self.__options.opcode)
         elif self.__options.memstr:   return self.__lookingForMemStr(self.__options.memstr)
-        else: 
+        else:
             self.__getGadgets()
             self.__lookingForGadgets()
             if self.__options.ropchain:
@@ -218,7 +219,7 @@ class Core(cmd.Cmd):
     # Console methods  ============================================
 
     def do_binary(self, s, silent=False):
-        # Do not split the filename with spaces since it might contain 
+        # Do not split the filename with spaces since it might contain
         # whitespaces
         if len(s) == 0:
             if not silent:
@@ -267,7 +268,7 @@ class Core(cmd.Cmd):
         if not silent:
             print("[+] Gadgets loaded !")
 
-        
+
     def help_load(self):
         print("Syntax: load -- Load all gadgets")
         return False
@@ -330,7 +331,7 @@ class Core(cmd.Cmd):
             if a not in gadget:
                 return False
         return True
-        
+
     def __withoutK(self, listK, gadget):
         for a in listK:
             if a in gadget:
@@ -459,6 +460,7 @@ class Core(cmd.Cmd):
         print("Range:       %s" %(self.__options.range))
         print("RawArch:     %s" %(self.__options.rawArch))
         print("RawMode:     %s" %(self.__options.rawMode))
+        print("RawEndian:   %s" %(self.__options.rawEndian))
         print("Re:          %s" %(self.__options.re))
         print("String:      %s" %(self.__options.string))
         print("Thumb:       %s" %(self.__options.thumb))
